Index: trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx	(revision 5417)
+++ trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx	(revision 5418)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.cxx,v $
-//= $Revision: 1.33 $
+//= $Revision: 1.34 $
 //= $Author: moralejo $ 
-//= $Date: 2004-10-26 13:58:59 $
+//= $Date: 2004-11-17 11:36:07 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -118,5 +118,6 @@
 static int   selected_pixel = -1; // Selected pixel: if >= 0 ==> only this pixel is filled! 
 
-static int   gain_fluctuations = 1; // Is 0 if PMT gain fluctuations are disabled
+static int   gain_fluctuations = 1; // Is 0 if PMT gain fluctuations are disabled for signal
+static int   noise_gain_fluctuations = 1; // Is 0 if PMT gain fluctuations are disabled for NSB noise
 
 // Coordinates of CT locations, in centimeters, in the Corsika system.
@@ -629,4 +630,10 @@
       break;
 
+    case noise_gain_fluctuations_off:
+
+      noise_gain_fluctuations = 0;
+
+      break;
+
     case end_file:            //@< end of the parameters file
 
@@ -1411,4 +1418,9 @@
 }
   
+int apply_noise_gain_fluctuations()
+{
+  return noise_gain_fluctuations;
+}
+  
 
 //=------------------------------------------------------------
@@ -1418,4 +1430,8 @@
 //
 // $Log: not supported by cvs2svn $
+// Revision 1.33  2004/10/26 13:58:59  moralejo
+//
+// Added option gain_fluctuations_off
+//
 // Revision 1.32  2004/10/14 16:53:49  moralejo
 //
Index: trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 5417)
+++ trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 5418)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.h,v $
-//= $Revision: 1.29 $
+//= $Revision: 1.30 $
 //= $Author: moralejo $ 
-//= $Date: 2004-10-26 13:58:59 $
+//= $Date: 2004-11-17 11:36:07 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -116,5 +116,6 @@
 T(mirror_fraction), /* Fraction of dish mirror really operative */ \
 T(calibration_run), /* option to produce a calibration file */ \
-T(gain_fluctuations_off), /* Switches off PMT gain fluctuations */ \
+T(gain_fluctuations_off), /* Switches off PMT gain fluctuations for signal */ \
+T(noise_gain_fluctuations_off), /* Switches off PMT gain fluctuations for NSB noise */ \
 T(end_file)         /* end of the parameters file */
 
@@ -197,4 +198,5 @@
  				 float *sigma_time, int *nevents, int *selected_pixel);
 int   apply_gain_fluctuations();
+int   apply_noise_gain_fluctuations();
 //!@}
 
@@ -212,4 +214,8 @@
 /*
  * $Log: not supported by cvs2svn $
+ * Revision 1.29  2004/10/26 13:58:59  moralejo
+ *
+ * Added option gain_fluctuations_off
+ *
  * Revision 1.28  2004/10/13 17:05:05  moralejo
  * *** empty log message ***
